@@ -1,9 +1,10 @@
 import logging
 import django
 from django.db import models
-from django.db.models.expressions import Col
 from django.db.models.sql.where import WhereNode
+from django.conf import settings
 
+from .exceptions import EmptyTenant
 from .utils import get_current_tenant, get_tenant_column, get_tenant_filters
 
 logger = logging.getLogger(__name__)
@@ -39,22 +40,27 @@ class TenantForeignKey(models.ForeignKey):
         current_tenant = get_current_tenant()
         if current_tenant:
             return get_tenant_filters(self.related_model)
-        else:
-            logger.warning(
-                "TenantForeignKey field %s.%s "
-                "accessed without a current tenant set. "
-                "This may cause issues in a partitioned environment. "
-                "Recommend calling set_current_tenant() before accessing "
-                "this field.",
-                self.model.__name__,
-                self.name,
-            )
-            return super(TenantForeignKey, self).get_extra_descriptor_filter(instance)
+
+        empty_tenant_message = (
+            f"TenantForeignKey field {self.model.__name__}.{self.name} "
+            "accessed without a current tenant set. "
+            "This may cause issues in a partitioned environment. "
+            "Recommend calling set_current_tenant() before accessing "
+            "this field."
+        )
+
+        if getattr(settings, "TENANT_STRICT_MODE", False):
+            raise EmptyTenant(empty_tenant_message)
+
+        logger.warning(empty_tenant_message)
+        return super().get_extra_descriptor_filter(instance)
 
     # Override
     # Django 4.0 removed the where_class argument from this method, so
     # depending on the version we define the function with a different
     # signature.
+    # pylint: disable=unused-argument,arguments-differ
+
     if django.VERSION >= (4, 0):
 
         def get_extra_restriction(self, alias, related_alias):
@@ -106,4 +112,4 @@ class TenantOneToOneField(models.OneToOneField, TenantForeignKey):
     # Override
     def __init__(self, *args, **kwargs):
         kwargs["unique"] = False
-        super(TenantOneToOneField, self).__init__(*args, **kwargs)
+        super().__init__(*args, **kwargs)
